@@ -13,8 +13,10 @@
 #include <flint/fmpq.h>
 #include <flint/fmpz_vec.h>
 
-#include "../e-antic/fmpz_poly_extra.h"
-#include "../e-antic/fmpq_poly_extra.h"
+#include "../../e-antic/config.h"
+
+#include "../../e-antic/fmpz_poly_extra.h"
+#include "../../e-antic/fmpq_poly_extra.h"
 
 static __inline__ int
 arb_sgn2(arb_t a)
