@@ -16,7 +16,9 @@
 
 #include <flint/fmpz_vec.h>
 
-#include "../e-antic/fmpz_poly_extra.h"
+#include "../../e-antic/config.h"
+
+#include "../../e-antic/fmpz_poly_extra.h"
 
 slong _fmpz_poly_descartes_bound_0_1(fmpz * p, slong len, slong bound)
 {
