@@ -11,7 +11,9 @@
 
 #include <stdlib.h>
 
-#include "../e-antic/fmpz_poly_extra.h"
+#include "../../e-antic/config.h"
+
+#include "../../e-antic/fmpz_poly_extra.h"
 
 slong fmpz_poly_num_real_roots_0_1_sturm(fmpz_poly_t pol)
 {
