@@ -9,8 +9,10 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
-#include "../e-antic/fmpz_poly_extra.h"
-#include "../e-antic/fmpq_poly_extra.h"
+#include "../../e-antic/config.h"
+
+#include "../../e-antic/fmpz_poly_extra.h"
+#include "../../e-antic/fmpq_poly_extra.h"
 
 int fmpz_poly_set_str_pretty(fmpz_poly_t p, const char * s, const char * var)
 {
