@@ -9,7 +9,9 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
-#include "../e-antic/renf.h"
+#include "../../e-antic/config.h"
+
+#include "../../e-antic/renf.h"
 
 slong renf_degree(renf_t nf)
 {
