@@ -12,7 +12,9 @@
 
 #include <string.h>
 
-#include "../e-antic/renf.h"
+#include "../../e-antic/config.h"
+
+#include "../../e-antic/renf.h"
 
 char * renf_get_str(const renf_t nf, const char * var, slong prec)
 {
