@@ -10,8 +10,10 @@
 */
 
 
-#include "../e-antic/renf_elem.h"
-#include "../e-antic/fmpq_poly_extra.h"
+#include "../../e-antic/config.h"
+
+#include "../../e-antic/renf_elem.h"
+#include "../../e-antic/fmpq_poly_extra.h"
 
 void renf_elem_set_fmpq_poly(renf_elem_t a, const fmpq_poly_t pol, const renf_t nf)
 {
