@@ -12,6 +12,7 @@
 
 #include <iostream>
 #include <cassert>
+#include <gmp.h>
 #include <flint/fmpq.h>
 #include <cstdlib>
 #include <functional>
@@ -20,7 +21,12 @@
 #include <boost/optional.hpp>
 #include <boost/lexical_cast.hpp>
 
-#include "../e-antic/e-antic.hpp"
+#include "../e-antic/config.h"
+
+#include "../e-antic/renf_class.hpp"
+#include "../e-antic/renf_elem_class.hpp"
+
+#include "../e-antic/renf_elem.h"
 #include "../e-antic/fmpq_poly_extra.h"
 
 namespace eantic {
@@ -145,6 +151,80 @@ renf_elem_class& binop(renf_elem_class& lhs, const renf_elem_class& rhs)
     return lhs;
 }
 
+template <
+  void renf_op(renf_elem_t, const renf_elem_t, const renf_elem_t, const renf_t),
+  void fmpz_op(renf_elem_t, const renf_elem_t, const fmpz_t, const renf_t),
+  void fmpq_op(renf_elem_t, const renf_elem_t, const fmpq_t, const renf_t)
+>
+renf_elem_class& ternop(renf_elem_class& lhs, const renf_elem_class& a, const renf_elem_class& b)
+{
+    if (lhs.parent() == a.parent())
+    {
+        if (a.parent() == b.parent())
+        {
+            renf_op(lhs.renf_elem_t(), a.renf_elem_t(), b.renf_elem_t(), lhs.parent().renf_t());
+        }
+        else if (b.is_integer())
+        {
+            fmpz_op(lhs.renf_elem_t(), a.renf_elem_t(), renf_elem_get_fmpz(b.renf_elem_t(), b.parent().renf_t()), lhs.parent().renf_t());
+        }
+        else if (b.is_rational())
+        {
+            fmpq_t buffer;
+            fmpq_init(buffer);
+            fmpq_op(lhs.renf_elem_t(), a.renf_elem_t(), renf_elem_get_fmpq(buffer, b.renf_elem_t(), b.parent().renf_t()), lhs.parent().renf_t());
+            fmpq_clear(buffer);
+        }
+        else
+        {
+            throw std::logic_error("cannot perform arithmetic with element in different number fields");
+        }
+    }
+    else if (a.is_integer())
+    {
+        ternop<renf_op, fmpz_op, fmpq_op>(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpz(a.renf_elem_t(), a.parent().renf_t())), b);
+    }
+    else if (a.is_rational())
+    {
+        fmpq_t buffer;
+        fmpq_init(buffer);
+        ternop<renf_op, fmpz_op, fmpq_op>(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpq(buffer, a.renf_elem_t(), a.parent().renf_t())), b);
+        fmpq_clear(buffer);
+    }
+    else
+    {
+        throw std::invalid_argument("arguments must be in the same number field");
+    }
+    return lhs;
+}
+
+template <
+  typename Integer,
+  void op(renf_elem_t, const renf_elem_t, const Integer, const renf_t)
+>
+renf_elem_class& ternop_primitive(renf_elem_class& lhs, const renf_elem_class& a, const Integer b) {
+    if (lhs.parent() == a.parent())
+    {
+        op(lhs.renf_elem_t(), a.renf_elem_t(), b, lhs.parent().renf_t());
+    }
+    else if(a.is_integer())
+    {
+        ternop_primitive<Integer, op>(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpz(a.renf_elem_t(), a.parent().renf_t())), b);
+    }
+    else if (a.is_rational())
+    {
+        fmpq_t buffer;
+        fmpq_init(buffer);
+        ternop_primitive<Integer, op>(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpq(buffer, a.renf_elem_t(), a.parent().renf_t())), b);
+        fmpq_clear(buffer);
+    }
+    else
+    {
+        throw std::invalid_argument("arguments must be in the same number field");
+    }
+    return lhs;
+}
+
 template <void op(renf_elem_t, const renf_elem_t, const fmpz_t, const renf_t)>
 renf_elem_class& binop_mpz(renf_elem_class& lhs, const mpz_class& rhs)
 {
@@ -155,6 +235,35 @@ renf_elem_class& binop_mpz(renf_elem_class& lhs, const mpz_class& rhs)
     return lhs;
 }
 
+template <
+  void op(renf_elem_t, const renf_elem_t, const fmpz_t, const renf_t)
+>
+renf_elem_class& ternop_mpz(renf_elem_class& lhs, const renf_elem_class& a, const mpz_class& b) {
+    if (lhs.parent() == a.parent())
+    {
+        ::fmpz_t r;
+        fmpz_init_set_readonly(r, b.get_mpz_t());
+        op(lhs.renf_elem_t(), a.renf_elem_t(), r, lhs.parent().renf_t());
+        fmpz_clear_readonly(r);
+    }
+    else if(a.is_integer())
+    {
+        ternop_mpz<op>(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpz(a.renf_elem_t(), a.parent().renf_t())), b);
+    }
+    else if (a.is_rational())
+    {
+        fmpq_t buffer;
+        fmpq_init(buffer);
+        ternop_mpz<op>(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpq(buffer, a.renf_elem_t(), a.parent().renf_t())), b);
+        fmpq_clear(buffer);
+    }
+    else
+    {
+        throw std::invalid_argument("arguments must be in the same number field");
+    }
+    return lhs;
+}
+
 bool relop_mpz(const renf_elem_class& lhs, const mpz_class& rhs, const int cmp)
 {
     if (cmp == 0 && !lhs.is_integer())
@@ -184,6 +293,35 @@ renf_elem_class& binop_mpq(renf_elem_class& lhs, const mpq_class& rhs)
     return lhs;
 }
 
+template <
+  void op(renf_elem_t, const renf_elem_t, const fmpq_t, const renf_t)
+>
+renf_elem_class& ternop_mpq(renf_elem_class& lhs, const renf_elem_class& a, const mpq_class& b) {
+    if (lhs.parent() == a.parent())
+    {
+        ::fmpq_t r;
+        fmpq_init_set_readonly(r, b.get_mpq_t());
+        op(lhs.renf_elem_t(), a.renf_elem_t(), r, lhs.parent().renf_t());
+        fmpq_clear_readonly(r);
+    }
+    else if(a.is_integer())
+    {
+        ternop_mpq<op>(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpz(a.renf_elem_t(), a.parent().renf_t())), b);
+    }
+    else if (a.is_rational())
+    {
+        fmpq_t buffer;
+        fmpq_init(buffer);
+        ternop_mpq<op>(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpq(buffer, a.renf_elem_t(), a.parent().renf_t())), b);
+        fmpq_clear(buffer);
+    }
+    else
+    {
+        throw std::invalid_argument("arguments must be in the same number field");
+    }
+    return lhs;
+}
+
 bool relop_mpq(const renf_elem_class& lhs, const mpq_class& rhs, const int cmp)
 {
     if (cmp == 0 && !lhs.is_rational())
@@ -239,6 +377,34 @@ renf_elem_class & binop_maybe_fmpz(renf_elem_class& lhs, Integer rhs, const std:
     return lhs;
 }
 
+template <typename Integer>
+renf_elem_class & ternop_maybe_fmpz(renf_elem_class& lhs, const renf_elem_class& a, Integer b, const std::function<void(renf_elem_t, const renf_elem_t, Supported<Integer>, const renf_t)>& op, const std::function<void(renf_elem_t, const renf_elem_t, const fmpz_t, const renf_t)>& fmpz_op)
+{
+    if (lhs.parent() == a.parent())
+    {
+        maybe_fmpz(b,
+            [&](auto v) { op(lhs.renf_elem_t(), a.renf_elem_t(), v, lhs.parent().renf_t()); },
+            [&](const fmpz_t v) { fmpz_op(lhs.renf_elem_t(), a.renf_elem_t(), v, lhs.parent().renf_t()); });
+    }
+    else if(a.is_integer())
+    {
+        ternop_maybe_fmpz(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpz(a.renf_elem_t(), a.parent().renf_t())), b, op, fmpz_op);
+    }
+    else if (a.is_rational())
+    {
+        fmpq_t buffer;
+        fmpq_init(buffer);
+        ternop_maybe_fmpz(lhs, renf_elem_class(lhs.parent(), renf_elem_get_fmpq(buffer, a.renf_elem_t(), a.parent().renf_t())), b, op, fmpz_op);
+        fmpq_clear(buffer);
+    }
+    else
+    {
+        throw std::invalid_argument("arguments must be in the same number field");
+    }
+    return lhs;
+}
+
+
 template <typename Integer>
 bool relop_maybe_fmpz(const renf_elem_class& lhs, Integer rhs, const std::function<int(renf_elem_t, Supported<Integer>, renf_t)>& op)
 {
@@ -935,6 +1101,14 @@ renf_elem_class & renf_elem_class::operator/=(const renf_elem_class & rhs)
     return binop<renf_elem_div, renf_elem_div_fmpz, renf_elem_div_fmpq>(*this, rhs);
 }
 
+renf_elem_class & renf_elem_class::iaddmul(const renf_elem_class & a, const renf_elem_class & b) {
+    return ternop<renf_elem_addmul, renf_elem_addmul_fmpz, renf_elem_addmul_fmpq>(*this, a, b);
+}
+
+renf_elem_class & renf_elem_class::isubmul(const renf_elem_class & a, const renf_elem_class & b) {
+    return ternop<renf_elem_submul, renf_elem_submul_fmpz, renf_elem_submul_fmpq>(*this, a, b);
+}
+
 mpz_class renf_elem_class::floordiv(const renf_elem_class& rhs) const
 {
     if (parent() != rhs.parent())
@@ -1034,6 +1208,16 @@ renf_elem_class& renf_elem_class::operator/=(short rhs)
     return *this /= static_cast<long>(rhs);
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, short b)
+{
+    return iaddmul(a, static_cast<long>(b));
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, short b)
+{
+    return isubmul(a, static_cast<long>(b));
+}
+
 bool operator==(const renf_elem_class& lhs, short rhs) {
     if (rhs == 0)
         return lhs.is_zero();
@@ -1068,6 +1252,16 @@ renf_elem_class& renf_elem_class::operator/=(unsigned short rhs)
     return *this /= static_cast<unsigned long>(rhs);
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, unsigned short b)
+{
+    return iaddmul(a, static_cast<unsigned long>(b));
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, unsigned short b)
+{
+    return isubmul(a, static_cast<unsigned long>(b));
+}
+
 bool operator==(const renf_elem_class& lhs, unsigned short rhs) {
     return lhs == static_cast<unsigned long>(rhs);
 }
@@ -1100,6 +1294,16 @@ renf_elem_class& renf_elem_class::operator/=(int rhs)
     return *this /= static_cast<long>(rhs);
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, int b)
+{
+    return iaddmul(a, static_cast<long>(b));
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, int b)
+{
+    return isubmul(a, static_cast<long>(b));
+}
+
 bool operator==(const renf_elem_class& lhs, int rhs) {
     if (rhs == 0)
         return lhs.is_zero();
@@ -1134,6 +1338,16 @@ renf_elem_class& renf_elem_class::operator/=(unsigned int rhs)
     return *this /= static_cast<unsigned long>(rhs);
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, unsigned int b)
+{
+    return iaddmul(a, static_cast<unsigned long>(b));
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, unsigned int b)
+{
+    return isubmul(a, static_cast<unsigned long>(b));
+}
+
 bool operator==(const renf_elem_class& lhs, unsigned int rhs) {
     return lhs == static_cast<unsigned long>(rhs);
 }
@@ -1170,6 +1384,16 @@ renf_elem_class& renf_elem_class::operator/=(long rhs)
     return *this;
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, long b)
+{
+    return ternop_primitive<long, renf_elem_addmul_si>(*this, a, b);
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, long b)
+{
+    return ternop_primitive<long, renf_elem_submul_si>(*this, a, b);
+}
+
 bool operator==(const renf_elem_class& lhs, long rhs) {
     return renf_elem_equal_si(lhs.renf_elem_t(), rhs, lhs.nf->renf_t());
 }
@@ -1206,6 +1430,16 @@ renf_elem_class& renf_elem_class::operator/=(unsigned long rhs)
     return *this;
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, unsigned long b)
+{
+    return ternop_primitive<unsigned long, renf_elem_addmul_ui>(*this, a, b);
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, unsigned long b)
+{
+    return ternop_primitive<unsigned long, renf_elem_submul_ui>(*this, a, b);
+}
+
 bool operator==(const renf_elem_class& lhs, unsigned long rhs) {
     return renf_elem_equal_ui(lhs.renf_elem_t(), rhs, lhs.nf->renf_t());
 }
@@ -1242,6 +1476,16 @@ renf_elem_class& renf_elem_class::operator/=(long long rhs)
     return *this;
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, long long b)
+{
+    return ternop_maybe_fmpz<long long>(*this, a, b, renf_elem_addmul_si, renf_elem_addmul_fmpz);
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, long long b)
+{
+    return ternop_maybe_fmpz<long long>(*this, a, b, renf_elem_submul_si, renf_elem_submul_fmpz);
+}
+
 bool operator==(const renf_elem_class& lhs, long long rhs) {
     return relop_maybe_fmpz(lhs, rhs, renf_elem_equal_si);
 }
@@ -1278,6 +1522,16 @@ renf_elem_class& renf_elem_class::operator/=(unsigned long long rhs)
     return *this;
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, unsigned long long b)
+{
+    return ternop_maybe_fmpz<unsigned long long>(*this, a, b, renf_elem_addmul_ui, renf_elem_addmul_fmpz);
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, unsigned long long b)
+{
+    return ternop_maybe_fmpz<unsigned long long>(*this, a, b, renf_elem_submul_ui, renf_elem_submul_fmpz);
+}
+
 bool operator==(const renf_elem_class& lhs, unsigned long long rhs) {
     return relop_maybe_fmpz(lhs, rhs, renf_elem_equal_ui);
 }
@@ -1310,6 +1564,16 @@ renf_elem_class& renf_elem_class::operator/=(const mpz_class& rhs)
     return binop_mpz<renf_elem_div_fmpz>(*this, rhs);
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, const mpz_class& b)
+{
+    return ternop_mpz<renf_elem_addmul_fmpz>(*this, a, b);
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, const mpz_class& b)
+{
+    return ternop_mpz<renf_elem_submul_fmpz>(*this, a, b);
+}
+
 bool operator==(const renf_elem_class& lhs, const mpz_class& rhs) {
     return relop_mpz(lhs, rhs, 0);
 }
@@ -1342,6 +1606,16 @@ renf_elem_class& renf_elem_class::operator/=(const mpq_class& rhs)
     return binop_mpq<renf_elem_div_fmpq>(*this, rhs);
 }
 
+renf_elem_class& renf_elem_class::iaddmul(const renf_elem_class& a, const mpq_class& b)
+{
+    return ternop_mpq<renf_elem_addmul_fmpq>(*this, a, b);
+}
+
+renf_elem_class& renf_elem_class::isubmul(const renf_elem_class& a, const mpq_class& b)
+{
+    return ternop_mpq<renf_elem_submul_fmpq>(*this, a, b);
+}
+
 bool operator==(const renf_elem_class& lhs, const mpq_class& rhs) {
     return relop_mpq(lhs, rhs, 0);
 }
