@@ -10,9 +10,10 @@
 */
 
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
 
+#include "../../e-antic/config.h"
+
 #include "../../e-antic/fmpq_poly_extra.h"
 
 static void check_valid(char * s, char * var, char * ans)
@@ -148,7 +149,13 @@ int main(void)
 
         }
 
+#ifdef FLINT_TEST_CLEAR
+        FLINT_TEST_CLEAR(state)
+#else
+        // FLINT <3.2.2 calls this macro FLINT_TEST_CLEAR instead of FLINT_TEST_CLEANUP
         FLINT_TEST_CLEANUP(state)
+#endif
+
     }
 
     return 0;
