@@ -13,6 +13,8 @@
 
 #include <flint/fmpq_vec.h>
 
+#include "../../e-antic/config.h"
+
 #include "../../e-antic/fmpz_poly_extra.h"
 
 int main(void)
@@ -47,7 +49,12 @@ int main(void)
         fmpz_poly_clear(p);
     }
 
+#ifdef FLINT_TEST_CLEAR
+    FLINT_TEST_CLEAR(state)
+#else
+    // FLINT <3.2.2 calls this macro FLINT_TEST_CLEAR instead of FLINT_TEST_CLEANUP
     FLINT_TEST_CLEANUP(state)
+#endif
 
     return 0;
 }
