@@ -9,9 +9,10 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
+#include "../../e-antic/config.h"
+
 #include "../../e-antic/renf.h"
 #include "../../e-antic/renf_elem.h"
-#include "../../e-antic/fmpz_poly_extra.h"
 
 int main(void)
 {
@@ -52,7 +53,12 @@ int main(void)
         fmpq_poly_clear(p);
     }
 
+#ifdef FLINT_TEST_CLEAR
+    FLINT_TEST_CLEAR(state)
+#else
+    // FLINT <3.2.2 calls this macro FLINT_TEST_CLEAR instead of FLINT_TEST_CLEANUP
     FLINT_TEST_CLEANUP(state)
+#endif
 
     printf("PASS\n");
     return 0;
