@@ -9,13 +9,13 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
-#include <math.h>
 #include <stdlib.h>
 
 #include <flint/fmpz_vec.h>
 
+#include "../../e-antic/config.h"
+
 #include "../../e-antic/renf.h"
-#include "../../e-antic/fmpz_poly_extra.h"
 
 int main(void)
 {
@@ -51,6 +51,12 @@ int main(void)
         renf_clear(nf);
     }
 
+#ifdef FLINT_TEST_CLEAR
+    FLINT_TEST_CLEAR(state)
+#else
+    // FLINT <3.2.2 calls this macro FLINT_TEST_CLEAR instead of FLINT_TEST_CLEANUP
     FLINT_TEST_CLEANUP(state)
+#endif
+
     return 0;
 }
