@@ -9,6 +9,8 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
+#include "../../e-antic/config.h"
+
 #include "../../e-antic/renf.h"
 #include "../../e-antic/fmpz_poly_extra.h"
 
@@ -37,7 +39,12 @@ int main(void)
         for (i = 0; i < n; i++) renf_clear(nfemb + i);
     }
 
+#ifdef FLINT_TEST_CLEAR
+    FLINT_TEST_CLEAR(state)
+#else
+    // FLINT <3.2.2 calls this macro FLINT_TEST_CLEAR instead of FLINT_TEST_CLEANUP
     FLINT_TEST_CLEANUP(state)
+#endif
 
     return 0;
 }
