@@ -13,6 +13,8 @@
 
 #include <flint/flint.h>
 
+#include "../../e-antic/config.h"
+
 #include "../../e-antic/renf_elem.h"
 
 int main(void)
@@ -60,7 +62,13 @@ int main(void)
         fmpq_clear(d);
     }
 
+#ifdef FLINT_TEST_CLEAR
+    FLINT_TEST_CLEAR(state)
+#else
+    // FLINT <3.2.2 calls this macro FLINT_TEST_CLEAR instead of FLINT_TEST_CLEANUP
     FLINT_TEST_CLEANUP(state)
+#endif
+
     printf("PASS\n");
     return 0;
 }
