@@ -11,6 +11,8 @@
 */
 
 
+#include "../../e-antic/config.h"
+
 #include "../../e-antic/renf_elem.h"
 
 int main(void)
@@ -52,6 +54,12 @@ int main(void)
         renf_clear(nf);
     }
 
+#ifdef FLINT_TEST_CLEAR
+    FLINT_TEST_CLEAR(state)
+#else
+    // FLINT <3.2.2 calls this macro FLINT_TEST_CLEAR instead of FLINT_TEST_CLEANUP
     FLINT_TEST_CLEANUP(state)
+#endif
+
     return 0;
 }
