@@ -1,6 +1,6 @@
 /*
     Copyright (C)      2017 Vincent Delecroix
-                  2020-2022 Julian Rüth
+                  2020-2025 Julian Rüth
 
     This file is part of e-antic
 
@@ -10,7 +10,7 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
-#include "../../e-antic/e-antic.hpp"
+#include "../../e-antic/config.h"
 
 #include "../rand_generator.hpp"
 #include "../renf_class_generator.hpp"
@@ -198,6 +198,123 @@ TEST_CASE("Arithmetic with renf_elem_class", "[renf_elem_class][binop]")
         }
     }
 
+    SECTION("Addition and Subtraction of Products")
+    {
+        renf_elem_class c(a);
+
+        c.iaddmul(a, static_cast<short>(2));
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, static_cast<short>(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(a, static_cast<unsigned short>(2));
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, static_cast<unsigned short>(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(a, 2);
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, 2);
+        REQUIRE(c == a);
+
+        c.iaddmul(a, 2u);
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, 2u);
+        REQUIRE(c == a);
+
+        c.iaddmul(a, 2l);
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, 2l);
+        REQUIRE(c == a);
+
+        c.iaddmul(a, 2ul);
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, 2ul);
+        REQUIRE(c == a);
+
+        c.iaddmul(a, 2ll);
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, 2ll);
+        REQUIRE(c == a);
+
+        c.iaddmul(a, 2ull);
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, 2ull);
+        REQUIRE(c == a);
+
+        c.iaddmul(a, mpz_class(2));
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, mpz_class(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(a, mpq_class(2));
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, mpq_class(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(a, renf_elem_class(2));
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(a, renf_elem_class(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(2), a);
+        REQUIRE(c == 3 * a);
+
+        c.isubmul(renf_elem_class(2), a);
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(mpq_class(1, 2)), a);
+        c.iaddmul(renf_elem_class(mpq_class(1, 2)), a);
+        REQUIRE(c == 2 * a);
+
+        c.isubmul(renf_elem_class(mpq_class(1, 2)), a);
+        c.isubmul(renf_elem_class(mpq_class(1, 2)), a);
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(1), 2);
+        c.isubmul(renf_elem_class(1), 2);
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(mpq_class(1, 2)), 2);
+        c.isubmul(renf_elem_class(mpq_class(1, 2)), 2);
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(1), mpz_class(2));
+        c.isubmul(renf_elem_class(1), mpz_class(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(mpq_class(1, 2)), mpz_class(2));
+        c.isubmul(renf_elem_class(mpq_class(1, 2)), mpz_class(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(1), mpq_class(2));
+        c.isubmul(renf_elem_class(1), mpq_class(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(mpq_class(1, 2)), mpq_class(2));
+        c.isubmul(renf_elem_class(mpq_class(1, 2)), mpz_class(2));
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(1), 2ll);
+        c.isubmul(renf_elem_class(1), 2ll);
+        REQUIRE(c == a);
+
+        c.iaddmul(renf_elem_class(mpq_class(1, 2)), 2ll);
+        c.isubmul(renf_elem_class(mpq_class(1, 2)), 2ll);
+        REQUIRE(c == a);
+    }
+
     SECTION("Build Element as Sum of Terms")
     {
         auto c = K.zero();
