@@ -11,10 +11,13 @@
 
 #include <functional>
 
-#include "../../e-antic/e-antic.hpp"
+#include "../../e-antic/config.h"
 
 #include "../external/catch2/single_include/catch2/catch.hpp"
 
+#include "../../e-antic/renf_class.hpp"
+#include "../../e-antic/renf_elem_class.hpp"
+
 using namespace eantic;
 
 TEST_CASE("Consistency of Hash Function", "[renf_elem_class][hash]")
