@@ -12,7 +12,11 @@
 
 #include <limits.h>
 
-#include "../../e-antic/e-antic.hpp"
+#include "../../e-antic/config.h"
+
+#include "../../e-antic/renf.h"
+#include "../../e-antic/renf_class.hpp"
+#include "../../e-antic/renf_elem_class.hpp"
 
 using namespace eantic;
 
